%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% phdiceaa.cls                                                    %%
%% version 1.1                                                     %%
%% 2020-12-25                                                      %%
%% author: PF				                                       %%
%%                                                                 %%
%% This file is the LaTeX class for the thesis style               %%
%% of Ph.Diceaa                               					   %%
%%   															   %%
%%																   %%
%% Please let the Ph.D Coordinator or the current author know if   %%
%% any changes will be made at the present version of the          %% 
%% class. In any case, it is hardly recommended  to change the     %% 
%% class.                                                          %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Identification %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}[2009/01/01]
\ProvidesClass{phdiceaa}%
[2020/05/21 Univaq - Ph.Diceaa doctoral thesis class]

\def\PhD@classVersion{0.1}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Options %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{xkeyval}
\providecommand{\baseclass}{book}
\LoadClass[a4paper,11pt,twoside,openright]{book}

%\newif\ifPhD@customlanguage \PhD@customlanguagefalse
%\newcommand{\PhD@customlanguage}{}
%
%\define@key[phd]{}{italian}[]{\PhD@customlanguagetrue
%	\renewcommand{\PhD@customlanguage}{\PhD@italian}}
%\define@key[phd]{}{english}[]{\PhD@customlanguagetrue
%	\renewcommand{\PhD@customlanguage}{\PhD@english}}
%
%\define@key[phd]{}{bn}[]{\PhD@bntrue
%	\PassOptionsToPackage{monochrome}{color}
%	\PassOptionsToPackage{monochrome}{xcolor}}

\newlength{\PhD@binding}

\define@key[phd]{}{binding}[0pt]{\setlength{\PhD@binding}{#1}}


\RequirePackage{xkeyval}
\RequirePackage{etoolbox}
\RequirePackage{xparse}
\RequirePackage{babel} % Required for automatically changing names of document elements to languages besides english
\RequirePackage{scrbase} % Required for handling language-dependent names of sections/document elements
\RequirePackage{scrhack} % Loads fixes for various packages
\RequirePackage{setspace} % Required for changing line spacing
\RequirePackage{longtable} % Required for tables that span multiple pages (used in the symbols, abbreviations and physical constants pages)
\RequirePackage{siunitx} % Required for \SI commands
\RequirePackage{graphicx} % Required to include images
%\graphicspath{{Figures/}{./}} % Specifies where to look for included images
\RequirePackage{booktabs} % Required for better table rules
\RequirePackage{caption} % Required for customising the captions
\RequirePackage[innercaption,wide]{sidecap}  %  Required for side caption 
\RequirePackage{fancyhdr}  %Required for customising the page layout
\RequirePackage{amsmath} %Required for  maths stuff
\RequirePackage{amsthm}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{color,xcolor}
\RequirePackage{epigraph}
\RequirePackage{titlesec}
\RequirePackage{eso-pic}
\RequirePackage[round, sort, numbers, authoryear]{natbib}
\bibliographystyle{apalike}
\RequirePackage{marginnote}
\RequirePackage{afterpage}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Margins %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[a4paper,twoside]{geometry}
\geometry{textwidth=396pt,
	textheight=641pt,
	marginparsep=12pt,
	bindingoffset=\PhD@binding,
	vmarginratio=55:89,
	hmarginratio=55:89,
	includehead,
	marginparwidth=72pt,
	heightrounded}

%\geometry{bottom=3cm,outer=0.2 cm, inner=3.2cm, headsep=14pt,asymmetric,marginparwidth=72pt }


\setlength{\epigraphwidth}{0.7\textwidth}
\setlength{\topmargin}{-1.2 cm}
\setlength{\oddsidemargin}{0.2 cm}
\setlength{\evensidemargin}{3.2 cm}
\setlength{\textwidth}{12.5 cm}
\setlength{\textheight}{24.5 cm}
\linespread{1.2}\selectfont
\pagestyle{fancy}
\addtolength{\headwidth}{\marginparsep} 
\addtolength{\headwidth}{\marginparwidth}

\fancyhf{}
\renewcommand{\headrulewidth}{0.8pt} % Questo comando modifica lo spessore della linea nell'intestazione
\renewcommand{\footrulewidth}{2.5pt}% Questo comando modifica lo spessore della linea a pié di pagina.




%\let\tmp\evensidemargin
%\let\evensidemargin\oddsidemargin
%\let\oddsidemargin\tmp
%\reversemarginpar

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Page layout  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\chaptermark}[1]{%
	\markboth{#1}{}}

\fancyhead[RE]{}
\fancyhead[CE]{\bfseries\uppercase{
}}  
\fancyhead[RO]{\chaptermark} 
\fancyhead[LE]{Ph.D. Thesis of \theauthor, \laquilaname} 
\fancyhead[CO]{\bfseries\uppercase{}} 
\fancyhead[LO]{}

\fancyfoot[LE]{\thepage} % N.B.: nella pagina pari è presente solo il numero di pagina
\fancyfoot[RO]{\fcolorbox{black}{black}{\hspace{2. cm}\textcolor{white}{\thepage}}} % N.B.: nella pagina dispari è presente il numero di pagina di colore bianco racchiuso all'interno di un rettangolo nero
\fancyfoot[LO,CE]{ }
\fancyfoot[CO,RE]{ }


%setting of the setup
\captionsetup{format=plain,labelfont=bf,font={small,stretch=1.2},labelsep=period,justification=raggedright, twoside} 

%numering according the chapeter
\numberwithin{equation}{chapter}
\numberwithin{figure}{chapter}
\numberwithin{table}{chapter}
\setcounter{secnumdepth}{4}

%Caption setting setup

\DeclareCaptionJustification{raggedauto}{
	 \checkevenpage
	\ifevenpage \raggedright \else \raggedleft \fi}

\newcommand{\CustomCaption}[2][]{\ifodd\thepage \marginnote{\caption{#2}\label{#1}   }\captionsetup{format=plain,labelfont=bf,font={small,stretch=1.2},labelsep=period,justification=raggedauto, twoside}  
	\else
	\marginnote[\caption{#2}\label{#1}]{\null} \captionsetup{format=plain,labelfont=bf,font={small,stretch=1.2},labelsep=period,justification=raggedauto, twoside} 
	\fi}



%\captionsetup{format=plain,labelfont=bf,font={small,stretch=1.2},labelsep=period,twoside}

%numering according the chapeter
\numberwithin{equation}{chapter}
\numberwithin{figure}{chapter}
\numberwithin{table}{chapter}
\setcounter{secnumdepth}{4}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Chapter and section configuration%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\titleformat{\paragraph}
{\normalfont\normalsize\scshape}{\theparagraph}{1em}{}

\titlespacing*{\paragraph}
{0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}


\titleformat{\chapter}[display]
{\scshape \color{black}} 
{\Huge}
{3ex}
{\Huge}
{\filright}
{\linespread{1.5}\selectfont

\medskip
\bigskip
\bigskip}

\newcommand{\preNewChap}{
\newpage
\thispagestyle{empty}
	 \begin{center}
	 	[Blank page]
 \end{center} } 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Useful customized command  and environments %%%%%%%%%%%

\newcommand\Removeblankpage{\let\cleardoublepage\clearpage}

\newcommand\Background[1]{%
			\put(0,0){%
			\parbox[b][\paperheight]{\paperwidth}{%
			\vfill
			\centering
			
			\includegraphics[width=\paperwidth,height=\paperheight,%
			]{#1}%
			\vfill
					}
				}
			}

\newcommand{\makeAbsChap}[3][]{
	
	\newpage
	\@openrightfalse
	\cleardoublepage
	\thispagestyle{empty}

	\titleformat{\chapter}[display]
	{\scshape\color{black}} 
	{\Huge}
	{3ex}
	{\Huge}
	{\filright}
	\chapter{#2}
	\hrule 
	\medskip 
	\medskip
	\medskip
	\medskip
	
	\textbf{Chapter abstract}\\
	\linespread{1.1}\selectfont
	\begingroup
	\let\clearpage\relax
	\textbf{\include{#3}}
	\endgroup
	

 	\if\relax\detokenize{#1}\relax
 	\else
 	\AddToShipoutPicture{\Background{#1}}   
 	\linespread{1.5}\selectfont
 	\newpage	
 	\ClearShipoutPicture
 	\fi
 	
 	\linespread{1.5}\selectfont
 	\newpage	

	}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% Dedication %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	\newcommand\dedicatory[1]{
		{%\clearpage           % we want a new page          %% I commented this
			\thispagestyle{empty}% no header and footer
			\vspace*{\stretch{1}}% some space at the top
			\itshape             % the text is in italics
			\raggedleft         % flush to the right margin
			\large
		\hfill #1
		
		}
		
		{\par % end the paragraph
			\vspace{\stretch{3}} % space at bottom is three times that at the top
			\clearpage           % finish off the page
		}
	}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Abstract Environment English %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{abstractEN}[1][\AbstractLabelEN]
{\cleardoublepage\thispagestyle{plain}
	\noindent{\textsc{\Huge {#1}}}\par\vspace{1.5cm}\noindent\ignorespaces}
{\null\ignorespacesafterend}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Abstract Environment Italian  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{abstractIT}[1][\AbstractLabelIT]
{\cleardoublepage\thispagestyle{plain}
	\noindent{\textsc{\Huge #1}}\par\vspace{1.5cm}\noindent\ignorespaces}
{\null\ignorespacesafterend}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Acknowledgments Environment %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{acknowledgements}[1][\AcknowledgementLabel]
{\cleardoublepage\thispagestyle{plain}
	\noindent{\textsc{\Huge {#1}}}\par\vspace{1.5cm}\noindent\ignorespaces}
{\null\ignorespacesafterend}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% redefinition of the \maketitle command to generate the titlepage %

%% GENERAL COMMANDS

\let\titleoriginal\title           % save original \title macro
\renewcommand{\title}[1]{          % substitute for a new \title
	\titleoriginal{#1}%               % define the real title
	\newcommand{\thetitle}{#1}        % define \thetitle
}


\let\authororiginal\author         
\renewcommand{\author}[1]{         
	\authororiginal{#1}%               
	\newcommand{\theauthor}{#1}        	
}

\newcommand{\mynameCitation}[1]{\def\mynameCitation{\textbf{#1}}}

\newcommand{\subtitle}[1]{\def\subtitle{#1}}

\newcommand{\courseorganizer}[1]{\def\courseorganizerLabel{#1}}

\newcommand{\courseorganizerAcronym}[1]{\def\courseorganizerAcronym{#1}}

\newcommand{\course}[2][]{%
	\def\courseLabel{#2}
	\ifstrequal{#1}{override}{\overridecoursetrue}{}}

\newcommand{\copyyear}[1]{\def\copyyear{#1}}

\newcommand{\cycle}[1]{\def\cycle{#1}}

\newcommand{\submitdate}[1]{\def\submitdate{#1}}

\newcommand{\IDnumber}[1]{\def\IDnumber{#1}}

\newcommand{\SSD}[1]{\def\SSD{#1}}
\newcommand{\coursecoordinator}[1]{\def\coursecoordinator{#1}}
%Adivisor
\newcount\advisorcount
\newtoks\advisortoks
\newcommand{\advisor}[1]{% 
	\ifnum\advisorcount=0 
	\advisortoks={#1}% 
	\else 
	\advisortoks=\expandafter{\the\advisortoks\\[0.75mm]#1}% 
	\fi 
	\advance\advisorcount1}

%%%%% Co-Advisors or External Advisor 
\newcount\coadvisorcount
\newtoks\coadvisortoks
\newif\ifext \extfalse
\newcounter{numero}
\setcounter{numero}{0}
\newcommand{\coadvisor}[2][]{%
	\addtocounter{numero}{1}
	\ifnum\coadvisorcount=0
	\coadvisortoks={#2}% 
	\else 
	\coadvisortoks=\expandafter{\the\coadvisortoks\\[0.75mm]#2}% 
	\fi 
	\advance\coadvisorcount1
	\ifstrequal{#1}{ext}{\exttrue}{}}


%%%%% Reviewers
\def\ReviewerLabel{}
\newcommand{\Reviewerlabel}[1]{\def\ReviewerLabel{#1}}

\newcount\reviewercount
\newtoks\reviewertoks
\newcommand{\reviewer}[2]{%
	\ifnum\reviewercount=0
	\reviewertoks={{#1}\qquad {\textit{#2}}}% 
	\else 
	\reviewertoks=\expandafter{\the\reviewertoks\\[0.75mm]{{#1}\qquad {\textit{#2}}}}% 
	\fi 
	\advance\reviewercount1}  

%%%%% Directors
\newcount\directorcount
\newtoks\directortoks
\newcommand{\director}[1]{% 
	\ifnum\directorcount=0
	\directortoks={#1}% 
	\else 
	\directortoks=\expandafter{\the\directortoks\\[0.75mm]#1}% 
	\fi 
	\advance\directorcount1}



%\def\versiondate{}
\newcommand{\versiondate}[1]{\def\versiondate{#1}}

%\def\authoremail{}
\newcommand{\authoremail}[1]{\def\authoremail{#1}}

%\def\website{}
\newcommand{\website}[1]{\def\website{#1}}



%\def\copyrightstatement{}
\newcommand{\copyrightstatement}[1]{\def\copyrightstatement{#1}}

%\def\schoolname{}
\newcommand{\schoolname}[1]{\def\schoolname{#1}}

%\def\schooladdress{}
\newcommand{\schooladdress}[1]{\def\schooladdress{#1}}

%\def\schoolwebsite{}
\newcommand{\schoolwebsite}[1]{\def\schoolwebsite{#1}}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% PhD Thesis cover %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\makecoverPhD}{	\newgeometry{top=5mm, bottom=10mm, left=6.0 cm, right= 3 cm}
	\thispagestyle{empty}
	
	\newcommand\sfondo{	\put(0,0){%
			\parbox[b][\paperheight]{\paperwidth}{%
				\vfill
				\centering
				
				\includegraphics[width=\paperwidth,height=\paperheight,%
				]{Images/Logos/coverDICEAA.pdf}%
				\vfill}   }}
	\AddToShipoutPicture{\sfondo}
	
	\begin{titlepage}
		\begin{center}
%			\vspace*{.03\textheight}
			{\scshape\LARGE 	
				\centering
				\includegraphics[width=5cm]{Images/Logos/UnivAQ_logoA.png}\par}%\vspace{1.5cm} % Logo
%			\vspace*{.05\textheight}
			%			{\scshape\LARGE 	
			%				\centering
			%				\includegraphics[width=4cm,height = 4cm]{Images/Logos/logo.jpg}\par}
			\vspace{0.5cm} % Logo
			
			{\Large 	\textcolor{uaqgray}{\courseorganizerLabel} }\\[0.5 cm]
			\textsc{\Large \textcolor{diceaared}{Doctoral Thesis}}\\[0.5cm] % Thesis type
			
			
			
			\HRule	 \\[0.2cm] % Horizontal line
			{\huge \bfseries \linespread{1}\textcolor{diceaagray3}{\thetitle}\par}\vspace{0.4cm} % Thesis title
			\HRule \\[0.8cm] % Horizontal line
			
			
			
			\vfill
			{\LARGE Ph.D Course in \courseLabel\ \\[0.5cm]
				
				\cycle\ cycle }\\[0.2cm]
			
			
			%			\vfill		
			
			\if\subtitle
			\relax
			\else
			\vspace{0.4cm}
			\textcolor{diceaagray2}{\large\subtitle}\par
			\fi	
			
			\newcommand{\parboxP}[2][]{\hspace{0cm}\parbox[c][##1][c]{\linewidth}{##2}}
			\parindent=0pt
			
			
%			\vspace{\stretch{1}}
				
		\begin{center}
				\parboxP[2.5cm]{
				\makebox[\linewidth][c]{
				\parbox[c][][c]{0.5\textwidth}{
					\centering
					\CandidateLabel\\[1mm]
					{\large \textbf{\theauthor}}
				}
				
%				\vspace{\stretch{1}}

				\parbox[c][][c]{0.5\textwidth}{
					\centering
					\SSDLabel\\[1mm]
					{		\textbf{\SSD}}
				}	
				
		}	
		}
			\end{center}
		\vfill	
			
%					\vspace{\stretch{1}}
			\begin{center}
				\parbox[c][][c]{\textwidth}{
					\centering
					\coursecoordinatorLabel\\[2mm]
					{\large \textbf{\coursecoordinator}}}
				
				
			\end{center}
			
			
			
			
					\vspace{\stretch{1}}
			\parboxP[4.5cm]{
				\makebox[\linewidth][c]{	%
					\parbox[t][][c]{0.5\linewidth}{%
						\ifcase\advisorcount
						\ClassError{You must specify at least one advisor in the preamble}%
						{E.g. \protect\advisor{Prof. Name Surname}}
						\or
						\centering\ThesisAdvisorLabel\\[2mm]
						\else
						\centering\ThesisAdvisorsLabel\\[2mm]
						\fi
						{\large \textbf{\the\advisortoks}}}
					%					\hspace{1.5cm}
					
					
					
					
					\ifcase\coadvisorcount
					\relax
					\or
					\parbox[t][][c]{0.5\linewidth}{%
						\centering\ThesisCoAdvisorLabel\\[2mm]
						
						{\large \textbf{\the\coadvisortoks}}}
					
					\else
					\parbox[t][][c]{0.5\linewidth}{%
						\centering\ThesisCoAdvisorsLabel\\[2mm]
						
						{\large \textbf{\the\coadvisortoks}}}
					
					\fi	
				}
			}
			
%			\submitdate
%			\vfill
		\end{center}
	\end{titlepage}
	\ClearShipoutPicture  
	
	
	
		\newpage
	\null
	\thispagestyle{empty}
	
	\newpage
	\restoregeometry
	\thispagestyle{empty}
	
	\afterpage{%
		\newgeometry{top=3 cm, bottom=3 cm, left=4.5 cm, right= 4.5 cm}
		\begin{center}
						\vspace{3.5 cm}
						\vspace*{\fill}
						\decoRule\\
						\vspace{2 cm}
						\textsc{\Huge \thetitle}\\[2cm]
						
						\vspace{3 cm}
						
						\textbf{\Large \theauthor}\\[1cm]
						\textbf{\Large \the\advisortoks}\\[1cm]
						
						\vspace{2 cm}
						\decoRule\\
						
						\vspace*{\fill}
				\end{center}% material for this page
		\clearpage
		\restoregeometry
	} 
	
	
	
	

%%	\hspace{1cm}
%	\parbox[c][0.7\textheight][c]{\linewidth}{	\begin{center}
%			\vspace{3.5 cm}
%			\vspace*{\fill}
%			\decoRule\\
%			\vspace{2 cm}
%			\textsc{\Huge \thetitle}\\[2cm]
%			
%			\vspace{3 cm}
%			
%			\textbf{\Large \theauthor}\\[1cm]
%			\textbf{\Large \the\advisortoks}\\[1cm]
%			
%			\vspace{2 cm}
%			\decoRule\\
%			
%			\vspace*{\fill}
%	\end{center}}
	
	\clearpage
}





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% PhD ThesisSECOND cover %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\makecoverPhDsec}{	\newgeometry{top=5mm, bottom=10mm, left=8.5 cm, right= 3 cm}
	\thispagestyle{empty}
	
	\newcommand\sfondo{	\put(0,0){%
			\parbox[b][\paperheight]{\paperwidth}{%
				\vfill
				\centering
				
				\includegraphics[width=\paperwidth,height=\paperheight,%
				]{Images/Logos/cover2.pdf}%
				\vfill}   }}
	\AddToShipoutPicture{\sfondo}
	
	\begin{titlepage}
		\begin{center}
			
			\vspace*{.05\textheight}
%			{\scshape\LARGE 	
%				\centering
%				\includegraphics[width=4cm,height = 4cm]{Images/Logos/logo.jpg}\par}
			\vspace{1.5cm} % Logo
			
			{\Large 	\textcolor{uaqgray}{\courseorganizerLabel} }\\[0.5 cm]
			\textsc{\Large \textcolor{uaqgreen}{Doctoral Thesis}}\\[0.5cm] % Thesis type
			
			
			
			\HRule	 \\[0.4cm] % Horizontal line
			{\huge \bfseries \linespread{1}\textcolor{uaqgreen}{\thetitle}\par}\vspace{0.4cm} % Thesis title
			\HRule \\[0.8cm] % Horizontal line
			
			\if\subtitle
			\relax
			\else
			\vspace{0.4cm}
			\textcolor{uaqgreen}{\large\subtitle}\par\\[0.5 cm]
			\fi	
			
			\vfill
			{\LARGE Ph.D Course in \courseLabel\ \\[1cm]
				
				\cycle\ cycle }\\[0.3cm]
			
			
			%			\vfill		
			
			
			
			\newcommand{\parboxP}[2][]{\hspace{0cm}\parbox[c][##1][c]{\linewidth}{##2}}
			\parindent=0pt
			
			
			\vspace{\stretch{1}}
			
			\begin{center}
				\parbox[c][3cm][c]{\textwidth}{
					\centering
					\CandidateLabel\\[1mm]
					{\large \textbf{\theauthor}}\\[0.5mm]
				}
				
			\end{center}
			
			
			
			\parboxP[4.5cm]{
				\makebox[\linewidth][c]{	%
					\parbox[t][][c]{0.5\linewidth}{%
						\ifcase\advisorcount
						\ClassError{You must specify at least one advisor in the preamble}%
						{E.g. \protect\advisor{Prof. Name Surname}}
						\or
						\centering\ThesisAdvisorLabel\\[2mm]
						\else
						\centering\ThesisAdvisorsLabel\\[2mm]
						\fi
						{\large \textbf{\the\advisortoks}}}
					%					\hspace{1.5cm}
					
					\ifcase\coadvisorcount
					\relax
					\or
					\parbox[t][][c]{0.5\linewidth}{%
						\centering\ThesisCoAdvisorLabel\\[2mm]
						
						{\large \textbf{\the\coadvisortoks}}}
					
					\else
					\parbox[t][][c]{0.5\linewidth}{%
						\centering\ThesisCoAdvisorsLabel\\[2mm]
						
						{\large \textbf{\the\coadvisortoks}}}
					
					\fi	
				}
			}
			
			\submitdate
			\vfill
		\end{center}
	\end{titlepage}
	\ClearShipoutPicture  

 
	\newpage
	\null
	\thispagestyle{empty}
	
	\newpage
	\restoregeometry
	\thispagestyle{empty}
\hspace{-2cm}
\parbox[c][0.7\textheight][c]{\linewidth}{	\begin{center}
		
		\vspace*{\fill}
		\decoRule\\
		\vspace{2 cm}
		\textsc{\Huge \thetitle}\\[2cm]
		
		\vspace{3 cm}
		
		\textbf{\Large \theauthor}\\[1cm]
		\textbf{\Large \the\advisortoks}\\[1cm]
		
		\vspace{2 cm}
		\decoRule\\
		
		\vspace*{\fill}
\end{center}}

	\clearpage
}







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Macro for the back of the title page %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\composebacktitlepage{%
	
	{	\thispagestyle{empty}
%		\let\tmp\evensidemargin
%		\let\evensidemargin\oddsidemargin
%		\let\oddsidemargin\tmp
%		\reversemarginpar
			
		\parindent = 0pt
		\null
		
		\vspace{5cm}
		
		\ifcase\reviewercount
		\relax
		\else
		Reviewers: \\
		
		\the\reviewertoks\\%
		\fi
		
		\vfill
		
		\hrulefill
		\vspace{2mm}
		
		\small
		\textbf{\thetitle} \\[0.75mm]
		
		\theauthor\\
		\if\IDnumber
		\relax
		\else
		\IDnumberLabel:\ \IDnumber\\[0.9mm]
		\fi
		
		\courseorganizerLabel - \courseorganizerAcronym\\
		\laquilaname \\
		%		
		
		
		
		Copyright \copyright\ \copyyear,\ \theauthor. \allRightsReservedLabel.\\
				
				
		 \if\copyrightstatement
		 \relax
		 \else
		 \copyrightstatement
		 \fi
		\vspace{1.5mm}		 
%				
		\uaqthesisInformationLabel\\
		
		\if\versiondate
		\relax
		\else
		\versionLabel: \versiondate \\[2mm]%
		\fi
		
		
		\if\website
		\relax
		\else
		\websiteLabel: \website \\[2mm]%
		\fi
		\cleardoublepage
\restoregeometry	
	}

}


\newcommand{\CandidateLabel}{Candidate}
\newcommand{\CandidateLabelFemale}{Candidate}
\newcommand{\IDnumberLabel}{Candidate ID number}
\newcommand{\ThesisAdvisorLabel}{Thesis Tutor}
\newcommand{\ThesisAdvisorsLabel}{Thesis Tutors}
\newcommand{\ThesisCoAdvisorLabel}{Co-Tutor}
\newcommand{\ThesisCoAdvisorsLabel}{Co-Tutors}
\newcommand{\ThesisExtAdvisorLabel}{External Tutor}
\newcommand{\ThesisExtAdvisorsLabel}{External Tutors}
\newcommand{\SSDLabel}{SSD}
\newcommand{\coursecoordinatorLabel}{Course Coordinator}
\newcommand{\laquilaname}{University of L'Aquila}
\newcommand{\versionLabel}{Version}
\newcommand{\websiteLabel}{Website}
\newcommand{\AcknowledgementLabel}{Acknowledgements}
\newcommand{\AbstractLabelEN}{Abstract}
\newcommand{\AbstractLabelIT}{Sommario}
\newcommand{\allRightsReservedLabel}{All rights reserved}
\newcommand{\uaqthesisInformationLabel}{This thesis has been typeset by \LaTeX\ and phdiceaa class. }
\newcommand{\emailLabel}{Author's email}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Customized list of figures and tables%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\contentsname}{Table of contents}
\renewcommand{\listfigurename}{List of Figures}
\renewcommand{\listtablename}{List of Tables}
\renewcommand{\bibname}{References}
\setcounter{secnumdepth}{4}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Customized colors  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\definecolor{uaqgreen}{RGB}{161,151,68}
\definecolor{uaqyellow}{RGB}{244,197,69}
\definecolor{uaqgray}{RGB}{35,31,32}
\definecolor{diceaagray1}{RGB}{207,211,214}
\definecolor{diceaagray2}{RGB}{127,131,134}
\definecolor{diceaagray3}{RGB}{88,87,92}
\definecolor{diceaared}{RGB}{235,28,34}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Customized line %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\HRule}{\rule{.75\linewidth}{.6pt}} % New command to make the lines in the title page
\newcommand{\decoRule}{\rule{.6\textwidth}{2.pt}} % New command for a rule to be used under figures